4.22. umbra.components.factory.scriptEditor.views — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.22. umbra.components.factory.scriptEditor.views

views.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Views.

Others:

## 4.22.1. Module Attributes

`umbra.components.factory.scriptEditor.views.` `LOGGER`

## 4.22.2. Classes

class `umbra.components.factory.scriptEditor.views.` `SearchResults_QTreeView`(parent, model=None, readOnly=False, message=None)

  Bases: `umbra.ui.views.Abstract_QTreeView`

  This class is used to display Database Ibl Sets columns.

  Parameters: | parent – Object parent. ( QObject ) readOnly – View is read only. ( Boolean ) message – View default message when Model is empty. ( String )

  `treeViewIndentation`

    This method is the property for self.__treeViewIndentation attribute.

    Returns: | self.__treeViewIndentation. ( Integer )

class `umbra.components.factory.scriptEditor.views.` `ScriptEditor_QTabWidget`(parent)

  Bases: `PyQt4.QtGui.QTabWidget`

  This class is a QTabWidget subclass used to display `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` editors.
  It provides support for drag’n’drop by reimplementing relevant methods.

  Parameters: | parent – Parent object. ( QObject )

  `contentDropped`

    This signal is emited by the `ScriptEditor_QTabWidget` class when it receives dropped content. ( pyqtSignal )

    Returns: | Event. ( QEvent )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `dragEnterEvent`(event)

    This method reimplements the `QTabWidget.dragEnterEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

  `dragMoveEvent`(event)

    This method reimplements the `QTabWidget.dragMoveEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

  `dropEvent`(event)

    This method reimplements the `QTabWidget.dropEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »